summaryrefslogtreecommitdiff
path: root/src/render/graphicsdef.hpp
diff options
context:
space:
mode:
authorAndrei Karas <akaras@inbox.ru>2016-04-17 23:06:06 +0300
committerAndrei Karas <akaras@inbox.ru>2016-04-17 23:06:56 +0300
commitdba0611175c8d4a56dfbc918ccef139351e5c3e0 (patch)
treeb3c7a5684604facc0f0f5656fe373958c53dc5ad /src/render/graphicsdef.hpp
parent53530f76275df76406a9ce438a33df78c50d0948 (diff)
downloadplus-dba0611175c8d4a56dfbc918ccef139351e5c3e0.tar.gz
plus-dba0611175c8d4a56dfbc918ccef139351e5c3e0.tar.bz2
plus-dba0611175c8d4a56dfbc918ccef139351e5c3e0.tar.xz
plus-dba0611175c8d4a56dfbc918ccef139351e5c3e0.zip
Revert "Remove override keyword, if it present with final."
This reverts commit 55480eb4477b2cf85af1bcdcc5e8ec4f4ce6682d.
Diffstat (limited to 'src/render/graphicsdef.hpp')
-rw-r--r--src/render/graphicsdef.hpp52
1 files changed, 26 insertions, 26 deletions
diff --git a/src/render/graphicsdef.hpp b/src/render/graphicsdef.hpp
index 455e6ec5d..7e2b349e2 100644
--- a/src/render/graphicsdef.hpp
+++ b/src/render/graphicsdef.hpp
@@ -28,15 +28,15 @@ public:
void drawImageRect(int x, int y,
int w, int h,
const ImageRect &restrict imgRect)
- restrict2 final;
+ restrict2 override final;
- void beginDraw() restrict2 final;
+ void beginDraw() restrict2 override final;
- void endDraw() restrict2 final;
+ void endDraw() restrict2 override final;
- void pushClipArea(const Rect &restrict area) restrict2 final;
+ void pushClipArea(const Rect &restrict area) restrict2 override final;
- void popClipArea() restrict2 final;
+ void popClipArea() restrict2 override final;
/**
* Draws a resclaled version of the image
@@ -44,11 +44,11 @@ public:
void drawRescaledImage(const Image *restrict const image,
int dstX, int dstY,
const int desiredWidth,
- const int desiredHeight) restrict2 final;
+ const int desiredHeight) restrict2 override final;
void drawPattern(const Image *restrict const image,
const int x, const int y,
- const int w, const int h) restrict2 final;
+ const int w, const int h) restrict2 override final;
void inline drawPatternInline(const Image *restrict const image,
const int x, const int y,
@@ -58,50 +58,50 @@ public:
const int x, const int y,
const int w, const int h,
const int scaledWidth,
- const int scaledHeight) restrict2 final;
+ const int scaledHeight) restrict2 override final;
void calcPattern(ImageVertexes *restrict const vert,
const Image *restrict const image,
const int x, const int y,
- const int w, const int h) const restrict2 final;
+ const int w, const int h) const restrict2 override final;
void calcPattern(ImageCollection *restrict const vert,
const Image *restrict const image,
const int x, const int y,
- const int w, const int h) const restrict2 final;
+ const int w, const int h) const restrict2 override final;
void calcTileVertexes(ImageVertexes *restrict const vert,
const Image *restrict const image,
- int x, int y) const restrict2 final
+ int x, int y) const restrict2 override final
A_NONNULL(2, 3);
void calcTileCollection(ImageCollection *restrict const vertCol,
const Image *restrict const image,
- int x, int y) restrict2 final;
+ int x, int y) restrict2 override final;
void drawTileVertexes(const ImageVertexes *restrict const vert)
- restrict2 final;
+ restrict2 override final;
void drawTileCollection(const ImageCollection
*restrict const vertCol) restrict2 final
A_NONNULL(2);
- void updateScreen() restrict2 final;
+ void updateScreen() restrict2 override final;
void calcWindow(ImageCollection *restrict const vertCol,
const int x, const int y,
const int w, const int h,
const ImageRect &restrict imgRect)
- restrict2 final A_NONNULL(2);
+ restrict2 override final A_NONNULL(2);
- void drawRectangle(const Rect &restrict rect) restrict2 final;
+ void drawRectangle(const Rect &restrict rect) restrict2 override final;
- void fillRectangle(const Rect &restrict rect) restrict2 final;
+ void fillRectangle(const Rect &restrict rect) restrict2 override final;
- void drawPoint(int x, int y) restrict2 final;
+ void drawPoint(int x, int y) restrict2 override final;
void drawLine(int x1, int y1,
- int x2, int y2) restrict2 final;
+ int x2, int y2) restrict2 override final;
bool setVideoMode(const int w, const int h,
const int scalle,
@@ -109,22 +109,22 @@ public:
const bool fs,
const bool hwaccel,
const bool resize,
- const bool noFrame) restrict2 final;
+ const bool noFrame) restrict2 override final;
void drawImage(const Image *restrict const image,
- int dstX, int dstY) restrict2 final;
+ int dstX, int dstY) restrict2 override final;
void copyImage(const Image *restrict const image,
- int dstX, int dstY) restrict2 final;
+ int dstX, int dstY) restrict2 override final;
void drawImageCached(const Image *restrict const image,
- int x, int y) restrict2 final;
+ int x, int y) restrict2 override final;
void drawPatternCached(const Image *restrict const image,
const int x, const int y,
- const int w, const int h) restrict2 final;
+ const int w, const int h) restrict2 override final;
- void completeCache() restrict2 final;
+ void completeCache() restrict2 override final;
private:
void inline calcImageRect(ImageVertexes *restrict const vert,
@@ -58,50 +58,50 @@ public:
void drawTileCollection(const ImageCollection
- *restrict const vertCol) restrict2 final
+ *restrict const vertCol) restrict2 override final
A_NONNULL(2);